import { __classPrivateFieldGet, __classPrivateFieldSet } from 'tslib';
import { TemplateString } from '@yukawa/chain-base-angular-client';
import { DOCUMENT } from '@angular/common';
import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject } from '@angular/core';
import * as i1 from '@angular/router';
import { NavigationEnd } from '@angular/router';
import { InjectionScope } from '@awesome-nodes/injection-factory';
import { filter, take } from 'rxjs';

const SPLASHSCREEN_ANIMATED_TOKEN = new InjectionToken('SPLASHSCREEN_ANIMATED_TOKEN');
const SPLASHSCREEN_LOG_LEVELS_TOKEN = InjectionScope
    .get('YUKAWA_SPLASHSCREEN', null)
    .addToken('SPLASHSCREEN_LOG_LEVELS_TOKEN');
class YukawaSplashScreenService {
    /**
     * Constructor
     */
    constructor(_document, _injector, _router) {
        this._document = _document;
        this._injector = _injector;
        this._router = _router;
        this.closSplashScreen = () => {
            this.hide(true);
        };
        // Hide it on the first NavigationEnd event
        this._router.events
            .pipe(filter(event => event instanceof NavigationEnd), take(1))
            .subscribe((routerEvent) => {
            if (YukawaSplashScreenService.logsAvailable) {
                window.addEventListener('close-splash-screen', this.closSplashScreen);
            }
        });
    }
    static get logsAvailable() {
        return window.logService.logsAvailable(...SPLASHSCREEN_LOG_LEVELS_TOKEN.value);
    }
    get hideClassName() {
        return this._injector.get(SPLASHSCREEN_ANIMATED_TOKEN)
            ? 'yukawa-splash-screen-hidden-animated'
            : 'yukawa-splash-screen-hidden';
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Public methods
    // -----------------------------------------------------------------------------------------------------
    /**
     * Show the splash screen
     */
    show() {
        this._document.body.classList.remove(this.hideClassName);
    }
    /**
     * Hide the splash screen
     */
    hide(force = false) {
        if (force || !YukawaSplashScreenService.logsAvailable) {
            window.removeEventListener('close-splash-screen', this.closSplashScreen);
            window.dispatchEvent(new Event('close-splash-screen'));
            this._document.body.classList.add(this.hideClassName);
            setTimeout(() => {
                var _a;
                const splashScreen = document.body.getElementsByTagName('yukawa-splash-screen');
                if (splashScreen.length === 0) {
                    throw new Error('Splash screen not found!');
                }
                (_a = splashScreen.item(0)) === null || _a === void 0 ? void 0 : _a.remove();
            }, 1000);
        }
    }
}
/** @nocollapse */ YukawaSplashScreenService.ɵfac = function YukawaSplashScreenService_Factory(t) { return new (t || YukawaSplashScreenService)(i0.ɵɵinject(DOCUMENT), i0.ɵɵinject(i0.Injector), i0.ɵɵinject(i1.Router)); };
/** @nocollapse */ YukawaSplashScreenService.ɵprov = /** @pureOrBreakMyCode */ i0.ɵɵdefineInjectable({ token: YukawaSplashScreenService, factory: YukawaSplashScreenService.ɵfac, providedIn: 'root' });
(function () {
    (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(YukawaSplashScreenService, [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], function () {
        return [{ type: Document, decorators: [{
                        type: Inject,
                        args: [DOCUMENT]
                    }] }, { type: i0.Injector }, { type: i1.Router }];
    }, null);
})();

var _YukawaSplashScreen_initialized, _YukawaSplashScreen_loggedSubscription, _YukawaSplashScreen_showLogPending;
// eslint-disable-next-line prefer-const
let SPLASH_SCREEN_TEMPLATE = TemplateString `<div id="app-logo"></div>

<div id="spinner">
    <div class="bounce1"></div>
    <div class="bounce2"></div>
    <div class="bounce3"></div>
</div>

<div id="app-log"></div>

<button class="mt-5 underline" onclick="window.logService.save('text')">${'downloadText'}</button>
<button class="mt-5 underline" onclick="window.logService.save('json')">${'downloadJson'}</button>
<button class="mt-5 underline" onclick="document.location.reload()">${'reload'}</button>
<button class="my-5 underline" onclick="window.dispatchEvent(new Event('close-splash-screen'))">${'close'}</button>`;
// eslint-disable-next-line prefer-const
let SPLASH_SCREEN_LOG_TEMPLATE = TemplateString `<h1>${'appLog'}</h1>
<div id="log-table-container" class="mt-4 overflow-y-scroll">
    <table class="h-full w-full relative">
        <thead class="sticky top-0">
            <tr>
                <td>${'type'}</td>
                <td>${'message'}</td>
            </tr>
        </thead>
        <tbody>${'logs'}</tbody>
    </table>
</div>`;
class YukawaSplashScreen extends HTMLElement {
    constructor() {
        super();
        _YukawaSplashScreen_initialized.set(this, false);
        _YukawaSplashScreen_loggedSubscription.set(this, void 0);
        _YukawaSplashScreen_showLogPending.set(this, void 0);
        if (this.isConnected) {
            this.init();
        }
    }
    get logs() {
        return window.logService.logs
            .map(log => `<tr class="${log.type}"><td>${log.type}</td><td>${log.message}</td></tr>`)
            .join('\n');
    }
    showLog() {
        if (!__classPrivateFieldGet(this, _YukawaSplashScreen_initialized, "f")) {
            if (__classPrivateFieldGet(this, _YukawaSplashScreen_showLogPending, "f")) {
                return;
            }
            __classPrivateFieldSet(this, _YukawaSplashScreen_showLogPending, setTimeout(() => this.showLog(), 1000), "f");
            return;
        }
        const log = this.querySelector('#app-log');
        const button = this.querySelectorAll('button');
        const spinner = this.querySelector('#spinner');
        if (!log) {
            throw new Error('Splash screen log element not found.');
        }
        if (!spinner) {
            throw new Error('Splash screen spinner element not found.');
        }
        spinner.classList.add('hide');
        const setLogHeight = () => {
            var _a;
            // get log table container height
            const logTableContainer = document.getElementById('log-table-container');
            let extendedHeight = Array.from(logTableContainer.children)
                .reduce((current, next) => current + next.offsetHeight, 0);
            // add sticky table header height
            const item = log.getElementsByTagName('thead').item(0);
            extendedHeight += (_a = item === null || item === void 0 ? void 0 : item.offsetHeight) !== null && _a !== void 0 ? _a : 0;
            // Set initial log container height
            log.style.setProperty('--extended-height', extendedHeight.toString() + 'px');
        };
        if (__classPrivateFieldGet(this, _YukawaSplashScreen_showLogPending, "f") != null) {
            setTimeout(() => {
                spinner.classList.add('hidden');
                log.innerHTML = SPLASH_SCREEN_LOG_TEMPLATE({
                    appLog: 'App Log',
                    type: 'Type',
                    message: 'Message',
                    logs: this.logs,
                });
                log.classList.add('show');
                setLogHeight();
                // Display action buttons
                button.forEach(_button => _button.classList.add('show'));
                const tbody = log.getElementsByTagName('tbody').item(0);
                if (!tbody) {
                    return;
                }
                const scrollTo = (logType) => {
                    const warnEntries = tbody.getElementsByClassName(logType);
                    if (warnEntries.length > 0) {
                        warnEntries.item(0).scrollIntoView({
                            block: 'end',
                            behavior: 'smooth',
                        });
                        return true;
                    }
                    return false;
                };
                for (const _logType of SPLASHSCREEN_LOG_LEVELS_TOKEN.value) {
                    if (scrollTo(_logType)) {
                        break;
                    }
                }
                __classPrivateFieldSet(this, _YukawaSplashScreen_showLogPending, null, "f");
            }, 500);
        }
        else {
            const tbody = log.getElementsByTagName('tbody').item(0);
            if (!tbody) {
                return;
            }
            tbody.innerHTML = this.logs;
            setLogHeight();
            tbody.scrollIntoView({
                block: 'end',
                behavior: 'smooth',
            });
        }
    }
    disconnectedCallback() {
        var _a;
        (_a = __classPrivateFieldGet(this, _YukawaSplashScreen_loggedSubscription, "f")) === null || _a === void 0 ? void 0 : _a.unsubscribe();
    }
    init() {
        document.addEventListener('app-loaded', () => {
            setTimeout(() => {
                if (!YukawaSplashScreenService.logsAvailable) {
                    return;
                }
                __classPrivateFieldSet(this, _YukawaSplashScreen_loggedSubscription, window.logService.logged.subscribe((logService, ea) => {
                    this.showLog();
                }), "f");
                this.showLog();
                window.addEventListener('close-splash-screen', () => {
                    var _a;
                    (_a = __classPrivateFieldGet(this, _YukawaSplashScreen_loggedSubscription, "f")) === null || _a === void 0 ? void 0 : _a.unsubscribe();
                });
            });
        });
        setTimeout(() => {
            this.innerHTML = SPLASH_SCREEN_TEMPLATE({
                downloadText: 'Download Log (Text)',
                downloadJson: 'Download Log (JSON)',
                reload: 'Reload App',
                close: 'Continue to App',
            });
            __classPrivateFieldSet(this, _YukawaSplashScreen_initialized, true, "f");
        }, 1000);
    }
}
_YukawaSplashScreen_initialized = new WeakMap(), _YukawaSplashScreen_loggedSubscription = new WeakMap(), _YukawaSplashScreen_showLogPending = new WeakMap();
customElements.define('yukawa-splash-screen', YukawaSplashScreen);

/**
 * Generated bundle index. Do not edit.
 */

export { SPLASHSCREEN_ANIMATED_TOKEN, SPLASHSCREEN_LOG_LEVELS_TOKEN, SPLASH_SCREEN_LOG_TEMPLATE, SPLASH_SCREEN_TEMPLATE, YukawaSplashScreenService };
//# sourceMappingURL=yukawa-chain-base-angular-comp-splash-screen.mjs.map
